==> qcad-3.26.2.0.tar.gz: qcad-3.26.2.0/ts/qcadgui_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>ExitTrialDialog</name>
    <message>
        <source>Trial Version</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Versión de prueba</translation>
    </message>
    <message>
        <source>QCAD Trial</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">QCAD versión de prueba</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Cannot find user manual at: %1</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">No se puede encontrar manual del usuario: %1</translation>
    </message>
    <message>
        <source>Unable to launch Qt Assistant (%1)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">No se puede iniciar Asistente de Qt (%1)</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+157"/>
        <source>Custom</source>
        <translation>Personalizado</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+195"/>
        <source>Grid</source>
        <translation>Rejilla</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>Fin</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>En entidad</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>Perpendicular</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>Tangencial</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>Centro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>Punto medio</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>Intersección</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>Referencia</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+172"/>
        <source>Invalid</source>
        <translation>Inválido</translation>
    </message>
</context>
<context>
    <name>RSingleApplication</name>
    <message>
        <source>This software is not intended for production use.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Este software no está diseñado para uso en producción.</translation>
    </message>
    <message>
        <source>To continue trying out QCAD, please restart the software.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Para continuar probando QCAD, reinicie el software.</translation>
    </message>
    <message>
        <source>To start using QCAD without any limitations, please buy the full version for a small license fee from %1.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Para empezar a utilizar QCAD, sin limitación, por favor, compre la versión completa por una tarifa de licencia pequeños de %1.</translation>
    </message>
</context>
</TS>

==> qcad-3.32.3.4.tar.gz: qcad-3.32.3.4/ts/qcadgui_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>RCadToolBar</name>
    <message>
        <location filename="../src/gui/RCadToolBar.cpp" line="+139"/>
        <source>Vertical/Horizontal</source>
        <translation>Vertical/Horizontal</translation>
    </message>
</context>
<context>
    <name>RCadToolBarPanel</name>
    <message>
        <location filename="../src/gui/RCadToolBarPanel.cpp" line="+23"/>
        <location line="+63"/>
        <source>Back</source>
        <translation>Volver</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+154"/>
        <source>Custom</source>
        <translation>Personalizado</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+211"/>
        <source>Grid</source>
        <translation>Rejilla</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>Fin</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>En entidad</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>Perpendicular</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>Tangencial</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>Centro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>Punto medio</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>Intersección</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>Referencia</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Distance</source>
        <translation>Distancia</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+188"/>
        <source>Invalid</source>
        <translation>Inválido</translation>
    </message>
</context>
</TS>
